@@ -73,6 +73,11 @@
         <source>ERROR: Nothing selected to paste</source>
         <translation>VIRHE: Ei liitettävää</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Cannot create symlink in this folder</source>
+        <translation>No se puede crear el enlace en esta carpeta</translation>
+    </message>
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>Not enough space to proceed.</source>
@@ -119,6 +124,11 @@
         <source>Extract destination</source>
         <translation>Purkamisen kohde</translation>
     </message>
+    <message>
+        <location filename="../home.cpp" line="10"/>
+        <source>Symlink destination</source>
+        <translation>Destino del enlace</translation>
+    </message>
 </context>
 <context>
     <name>Clipboard</name>
@@ -173,6 +183,11 @@
         <source>Open terminal here</source>
         <translation>Avaa konsoli tässä</translation>
     </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Create new symlink</source>
+        <translation>Crear nuevo enlace</translation>
+    </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Sort</source>
