@@ -73,6 +73,11 @@
         <source>ERROR: Nothing selected to paste</source>
         <translation>ERREUR: Rien n&apos;a été selectionner</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Cannot create symlink in this folder</source>
+        <translation>Impossible de créer un lien symbolique dans ce dossier</translation>
+    </message>
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>Not enough space to proceed.</source>
@@ -119,6 +124,11 @@
         <source>Extract destination</source>
         <translation>Extraire vers</translation>
     </message>
+    <message>
+        <location filename="../home.cpp" line="10"/>
+        <source>Symlink destination</source>
+        <translation>Destination du lien symbolique</translation>
+    </message>
 </context>
 <context>
     <name>Clipboard</name>
@@ -173,6 +183,11 @@
         <source>Open terminal here</source>
         <translation>Ouvrir un terminal ici</translation>
     </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Create new symlink</source>
+        <translation>Créer un nouveau lien symbolique</translation>
+    </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Sort</source>
@@ -862,7 +877,7 @@
     <message>
         <location filename="../extract.cpp" line="10"/>
         <source>Error extracting files. Incorrect password?</source>
-        <translation>Erreur d'extraction des fichiers. Mot de passe incorrect?</translation>
+        <translation>Erreur d&apos;extraction des fichiers. Mot de passe incorrect?</translation>
     </message>
     <message>
         <location filename="../extract.cpp" line="10"/>
